let serial;
let data;

let width = 400;
let height = 400;

function setup() {
    // Instantiate our SerialPort object
    serial = new p5.SerialPort();

    // Assuming the board is connected, let's open the connection to it
    // Use the FTDI ID
    serial.open("/dev/tty.usbserial-1440");

    /////// Register some callbacks ///////
    // When we connect to the underlying server
    serial.on('connected', () => { console.log("We are connected!"); });
    // When we get a list of serial ports that are available
    let portlist = serial.list();
    serial.on('list', gotList);
    // When or if we get an error
    serial.on('error', (err) => { console.log(err); });
    // When our serial port is opened and ready for read/write
    serial.on('open', () => { console.log("Serial Port is open!"); });
    // When we some data from the serial port
    serial.on('data', gotData);

    /////////// Setup general p5.js stuff ///////////
    createCanvas(width, height);
}//function setup


function draw() {
    background('rgba(255,255,255, 0.1)');
    
    if (data) {
        document.getElementById("text-value").innerHTML = data;
        circle(map(data, 0, 255, 0, width), height/2, 80);
    }//if

}//function draw

//////////////////// Serial Helper Functions ////////////////////
// Got the list of ports
function gotList(thelist) {
    // theList is an array of their names
    for (let i = 0; i < thelist.length; i++) {
        // Display in the console
        print(i + " " + thelist[i]);
    }//for i
}//function gotList

// There is data available to work with from the serial port
function gotData() {
    let inString = serial.readStringUntil('\r\n');
    // check to see that there's actually a string there:
    if (inString.length > 0) {
        // convert it to a number:
        data = Number(inString);
    }//if
}//function gotData
